# Nix
# Copyright (c) 2017  Mark Biciunas.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import argparse
import logging

from cli_nix import cli_run
from cli_nix import cli_tags
from cli_nix import cli_list
from cli_nix import cli_show

LOG = logging.getLogger(__name__)


class CLI:
    def __init__(self) -> None:
        """
        Create a command line argument parser for the Nix program.
        """
        LOG.debug("Create instance of {}".format(__name__))

        self._parser = argparse.ArgumentParser(description="Configure config file metadata.")

        _subparser = self._parser.add_subparsers(title='subcommands')

        cli_run.add_subparser(_subparser)
        cli_tags.add_subparser(_subparser)
        cli_list.add_subparser(_subparser)
        cli_show.add_subparser(_subparser)

    def print_help(self) -> None:
        """Print out the help as generated by the parser.

        In general, this will only be called when a user executes the
        program without providing any parameters.
        """
        self._parser.print_help()

    def start_parser(self) -> None:
        """Start the argument parser and process any command line
        parameters present.
        """
        args = self._parser.parse_args()

        args.func(args)
